<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LockAllLayers</name>
    <message>
        <location filename="../LockAllLayersInit.js" line="+2"/>
        <source>&amp;Lock All Layers</source>
        <translation>全てのレイヤーをロック</translation>
    </message>
</context>
<context>
    <name>ShowAllLayers</name>
    <message>
        <source>&amp;Show all Layers</source>
        <translation type="vanished">&amp;S 全ての画層を表示</translation>
    </message>
    <message>
        <source>&amp;Show All Layers</source>
        <translation type="vanished">&amp;S 全ての画層を表示</translation>
    </message>
</context>
</TS>
